sabato 30 gennaio 2010

ZOMBIE ME!


Zombie me è un'applicazione per iphone e ipod touch gratuita che permette

di modificare le nostre foto.

questa applicazione si distingue da tutte le altri applicazioni che servono per

modificare le foto per la particolarità di poter aggiungere particolari che

riescono a zombificare le nostre foto.

ecco il link per il download su apple store: Zombie Me

psp go modificata!!la falla è nei giochi

PSP GO invulnerabile!?non è così come sembra. Grazie a delle vulnerabilità presenti in alcuni giochi per la nuova console portatile Sony, l'hacker Freeplay è stato in grado di far girare del codice non verificato. Un bell'inizio per una console di cui si era detto che sarebbe stata inviolata.

L'hack si avvantaggia di file di salvataggio modificati ed è ristretto alla modalità utente quindi non è possibile inoculare firmware personalizzati. Freeplay non ha intenzione di condividere l'hack, ma questa è la prova che la nuova PSP potrebbe non essere a prova di homebrew.

Sempre in tema di PSP GO potete vedere anche la prima modifica estetica.

fujitsu vs apple


A lungo è stato chiamato iSlate dalle varie indiscrezioni,ma alla fine Steve Jobs ha finalmente optato per iPad.

un nome davvero semplicissimo da ricordare e la cui assonanza ricorda quella del lettori digitali dell'azienda della Mela i celeberrimi iPod. Secondo delle fonti non confermate il marchio "iPad" sarebbe già stato depositato da due aziende la STMicroelectronics e dalla Fujitsu

iPad di Fujitsu è un personal assistant destinato alle aziende, in particolare per la gestione degli stock di magazzino. Un obiettivo diverso da quello del tablet Apple. Fujitsu ha depositato il marchio "iPad" nel lontano 2003.

L'azienda giapponese si è finalmente svegliata nel giugno 2009 per far valere la sua paternità sul nome iPad, ma Apple è decisa a difendere i suoi interessi. per quanto riguarda STMicroelectronics, la situazione dovrebbe essere molto più semplice. L'azienda francese è infatti il fornitore esclusivo degli accelerometri destinati agli iPhone e molto certamente anche agli iPad.

LE VITTIME DELLA SHOAH CONTRO iMussolini

I superstiti americani dell'Olocausto hanno denunciano il fatto e descritto l'applicazione come "un insulto alla memoria di tutte le vittime del nazismo e del fascismo. E' uno scandalo che la società di Cupertino abbia approvato la presenza di quest'applicazione nel suo negozio online di iTunes store ed è una sconfitta per l'intero mercato mobile", ha dichiarato in un comunicato Elan Steinberg, vice presidente dei American Gathering of Holocaust Survivors and their descendants.

"Protestiamo e chiediamo ai dirigenti Apple di effettuare maggiori controlli sulle applicazioni disponibili, rendendosi anche responsabili dei contenuti", prosegue Steinberg, sottolineando che l'azione compiuta è "un insulto alla memoria di tutte le vittime del nazismo e fascismo, ebrei e non ebrei, e chiunque sia responsabile deve essere condannato in quanto ha commesso un'offesa alla decenza e alla coscienza".

L'applicazione è stata lanciata al prezzo di 0.79 euro, la cosa che scandalizza di più è che iMussolini èl'applicazione più venduta online su Apple Store Italia ed è stata scaricata circa 6500 volte.

Scaricare iMussolini "è come andare in una libreria e comprare un libro sul dittatore italiano", aggiunge lo sviluppatore che chiede agli utenti di astenersi dagli slogan fascisti.

sky cielo

Continua la lotta tra Sky, Mediaset e Rai, per la tv del futuro. Dopo avere trasformato i suoi decoder satellitari con una semplice chiavetta USB (che consentirà agli abbonati Sky di poter vedere anche il digitale terrestre), ora la TV di Murdoch sbarca sul terreno di gioco dei nemici. Anche Sky, infatti, creerà un canale per il digitale terrestre, per fare competizione diretta a Rai e Mediaset.


L'idea di Sky è quella di creare un canale gratuito, chiamato "Cielo", che aiuterà i non abbonati a capire il valore aggiunto della sua piattaforma rispetto alla restante offerta del digitale terrestre. Cielo sarà gestito dalla NewsCorp Station Europe e avrà come direttore Gary Davey(un nome di spicco dell'azienda, che evidentemente punta molto su questo debutto).

Sky, teoricamente, non potrebbe espandersi sul digitale terrestre fino a dicembre 2011, a causa delle leggi anti-trust europee. Le frequenze, tuttavia, non saranno acquistate ma semplicemente prese in affitto da Rete A, quindi si potrà iniziare già a dicembre. La speranza è quella di raggiungere in breve tempo tutte le famiglie già raggiunte dai canali Boing e Rai 4: non sarà facile, perché il mux di Rete A è stato aggiornato a rilento.

L'offerta di Cielo sarà eterogenea, con circa l'80% di prodotti inediti, in contemporanea con il satellite. Verranno offerti quiz, varietà, edizioni di Sky Tg24 (premiato come miglior tg del 2009), serie tv e produzioni italiane.

Da chi ha creato SKY una nuova TV

Sarà proprio l’informazione di SKY TG24 ad inaugurare la programmazione del canale martedì 1° dicembre alle ore 12.00. Cielo offrirà ben 4 edizioni giornaliere del TG (alle ore 7.00, 12.00, 19.00 e 24.00) in simulcast con il canale all-news di SKY, a cui si aggiungono nel fine settimana gli approfondimenti L’Intervista di Maria Latella, Io Reporter e FAD. Grazie alla collaborazione con SKYTG24, una struttura che si avvale di 430 persone tra cui 141 giornalisti, Cielo proporrà al suo pubblico un’informazione completa e autorevole. I generi più apprezzati ed amati degli ultimi anni, come i reality e i talent show, si alterneranno nel palinsesto alle serie americane di maggior successo. Dalle recentissime - e in prima assoluta per la tv in chiaro -Life on Mars, Lipstick Jungle, Sons of Anarchy, Burn Notice-Duro a Morire, The Riches - fino a veri e propri cult come X Files, 24 eBuffy L’Ammazzavampiri, tre serie pluripremiate che hanno rivoluzionato la storia di questo genere televisivo e che Cielo propone agli spettatori dalla prima stagione.

Attesissima dal grande pubblico è
Boris, la serie unanimemente considerata tra le più divertenti e graffianti della televisione italiana degli ultimi anni. A fare da contrappeso alla dissacrante comicità della sgangherata troupe di Boris, le drammatiche storie tutte al femminile di Donne Assassine, la serie composta da otto TV movie che vanta un cast d’eccezione con alcune delle più interessanti interpreti del cinema italiano. Tutto al femminile anche il cast de Il vizio dell’amore: 30 attrici interpretano 30 monologhi che parlano di amore, tradimenti e passioni.

Sempre sul fronte delle produzioni italiane, arrivano per la prima volta in chiaro su Cielo
Essere Valeria, la docu-soap in quattro puntate che segue la vita della prorompente diva italiana Valeria Marini, e due docu-reality che ci portano alla scoperta delle famiglie italiane in modo divertente e commovente: Cambio Moglie e Reparto Maternità.

Per quanto riguarda reality e talent show, generi che continuano da anni a riscuotere il favore del grande pubblico, Cielo propone
Italia’s Next Top Model, adattamento italiano del format Usa di grande successo, condotto da Natasha Stefanenko, e Vuoi ballare con me con Lorella Cuccarini, che mette a confronto sulla pista di ballo genitori e figli. Trova posto nel ricco palinsesto anche il divertente game show condotto da Massimiliano Ossini Sei più bravo di un ragazzino di 5a?.

Infine, il canale dispone di una ricca library di film e proporrà due serate speciali in prime-time di recenti blockbuster internazionali.

Domande e Risposte

E’ possibile vedere il canale digitale terrestre “Cielo” con qualsiasi tipo di decoder DTT?

Il canale digitale terrestre “Cielo” è visibile attraverso qualsiasi decoder DTT.

Per vedere il canale digitale terrestre “Cielo” occorrerà risintonizzare il decoder DTT dopo la data di lancio del canale?

Sì, per la ricezione del canale “Cielo” sul digitale terrestre sarà necessario risintonizzare i decoder DTT affinché questi possano ricevere il canale.

Per vedere il canale satellitare “Cielo” occorrerà risintonizzare il decoder satellitare SKY dopo la data di lancio del canale?

No, i decoder SKY sono in grado di sintonizzare automaticamente il nuovo canale.

Posso cambiare la numerazione preassegnata al canale digitale terrestre “Cielo”?

Dipende dal tipo di decoder DTT che si utilizza. Si consiglia pertanto di leggere il manuale d’istruzioni per maggiori dettagli.

Posso cambiare la numerazione preassegnata al canale satellitare “Cielo”?

Dipende dal tipo di decoder satellitare che si utilizza. Si consiglia pertanto di leggere il manuale d’istruzioni per maggiori dettagli.

Posso vedere il canale “Cielo” anche sulla piattaforma SKY? E avrà dei contenuti diversi?

Cielo sarà anche un canale satellitare, visibile sulla piattaforma SKY al canale n. 129. Il canale satellitare “Cielo” avrà i medesimi contenuti del canale digitale terrestre.

Cielo viene trasmesso anche in HD?

Non al momento.

sito:http://www.cielotv.it/

venerdì 29 gennaio 2010

Spegni il tuo pc con un file notepad


Molte volte sentiamo parlare di file batch come virus o comandi dannosi ma non è sempre cosi.

I file batch non sono altro che comandi che si danno ad un pc tramite cmd.
Naturalmente sono anche utili e rendono più veloce l’utilizzo del nostro pc.
In questo articolo vedremo come spegnere o riavviare un pc tramite comandi batch.
Iniziamo con lo spiegare come si crea un file batch…per farlo apriamo il blocco note, all’interno scriviamo il codice e poi salviamo con estensione .bat
ora procediamo con la scrittura dei comandi utili al nostro scopo:

shutdown -comando

al posto di -comando vanno qualcuno di questi a seconda delle necessità e del file batch che vogliamo creare:
-i : Attiva l’interfaccia utente grafica
-l : Disconnette l’utente
-r : Riavvia il PC
-s : Spegne il computer
-t xx: xx Sarebbero i secondi di attesa prima della chiusura di Windows
-f : Chiude le applicazioni ancora aperte

allora ecco facciamo un esempio
Per riavviare il pc
shutdown -r
per spegnere il pc dopo 40 secondi dall’apertura del batch
shutdown -s -t 40
dove -s è il comando per spegnere il pc e -t è il comando per impostare quanti secondi dopo l’apertura del batch il pc deve fare l’azione descritta in precedenza, per azioni intendo:
-r riavviare il pc
-s spegnere il pc
-l disconnettere l’utente
il comando -t è seguito dal numero dei secondi che si vogliono impostare.
per spegnere il pc dopo 40 secondi forzando la chiusura delle applicazioni ancora aperte
shutdown -s -t 40 -f
dove -s e -t abbiamo gia visto a cosa servono e -f forza la chiusura delle applicazioni ancora aperte.

Una volta creato il batch o più batch che ci servono per eseguirlo basta fare doppio click sul file creato.
Questa operazione ci renderà la vita più semplice dato che basterà un doppio click per spegnere/riavviare/disconnettere il pc.


istallare windows seven su netbook


Come saprete da qualche tempo è disponibile la release candidate ufficiale di Windows 7, ed oggi ho provato a installare il nuovo sistema operativo su un netbook Acer One. Risultato? Sembra incredibile ma è molto più veloce e performante adesso con Windows 7 che prima con Windows Xp e il sisitema sembra riconoscere automaticamente tutte le periferiche e driver!

Quindi vi spiego come installare nel modo più facile possibile Windows 7 su un netbook, quindi su un miniportatile non dotato di lettore CD/DVD,in questo caso un Acer One con processore Intel Atom da 1.6 Ghz e hd da 160 gb, ma dovrebbe girare bene anche con sistemi di caratteristiche inferiori,ecco come fare:


1- Scaricare la Build Ufficiale Windows 7 dal sito Microsoft.

2- Formattare una chiavetta USB da almeno 4 gb con sistema NTFS

3- montare l'immagine .iso di Windows 7 scaricata sulla chiavetta con Winrar o simili.

4- Collegare la chiavetta USB al netbbok e avviarla dal boot o direttamente dal desktop cliccando sul file Setup.

5- A questo punto parte l'installazione guidata di Windows 7.


6- Una volta avviato Windows 7 è possibile impostare la lingua italiana scaricando il language pack da Windows Update raggiungibile dal pannello di controllo.

Tutto qua, con poco più di un ora di lavoro avrete installato il nuovo Windows 7 sul vostro netbook

Apple Tablet: si chiamerà iPad


tap farm


Per tutti gli amanti di farm ville di facebook ecco un'applicazione che vi piacierà molto.

Tap farm è un'applicazione gratuita disponibile su apple store che ricrea per tutti gli amanti del genere un gioco per la gran parte simile a farm ville.
Ovvero per chi non l'avesse mai sentito nominare un gioco in cui devi costruirti una fattoria, seminare e racogliere piante e guadagnare soldi(virtuali) con cui puoi comprare altri oggetti(semi,alberi,animali,elementi decorativi,ecc...) che ti permetteranno di far salire di livello il
tuo personaggio
Dettagi: :: scaricare in .

get mu


Get Mu è un applicazione online che ci permette di scaricare dal famoso

sito megaupload come se fossimo degli utenti premium.

Si deve incollare l’URL del file che si vuole scaricare, si clicca sul

bottone “Dame el Link” e il sistema genera un link per il download diretto.

accaunt premium megaupdoal gratis


Ecco a voi come fare ad avere un account premium su megaupload gratis!!!!

Premessa: Questa procedura vi consentira di trasformare il vostro normalissimo account gratuito
di megaupload in un account premium, a partire dalle ore 03:00 di notte alle ore 09:00
del mattino seguente, l’happy hour (H.H.), appunto in cui la seguente procedura ha
effetto.

!ATTENZIONE! L’account premium rimarrà valido solo nella fascia oraria indicata, tutti i file presenti nella coda di download
di megamanager i cui download si siano avviati prima delle 11:00 arriveranno fino alla fine.yes


Procedura:

1) Creazione di un account gratuito su megaupload



Per la registrazione free, vi verrà solamente richiesto di inserire un nickname, una password, e un idirizzo mail valido,
dopo di che il vostro account sarà subito pronto.
!ATTENZIONE! Finita la registrazione loggatevi sul sito di megaupload (nella barra in alto)
in modo da essere attivi come utente free registrato (membro) (i cookie devono essere attivi per poter memorizzare la login).

2) Installazione della toolbar di megaupload

Su questo punto andate tranquilli, la toolbar di, megaupload è totalmente sicura, non contiene ne virus ne spyware,
ed è indispensabile per far funzionare il "Mio Trucchetto"!


Per installare la toolbar, basta andare su megaupload e cercarla.

3) “Bugerare”, le verifiche dell’ ip della vostra connessione con un proxy server degli stati uniti.

Adesso sarà necessario avere firefox, installato in quanto la procedura con I Explorer non è garantita,
non è collaudata e soprattutto non è così immediata come con firefox!
Per attivare un server proxy dentro firefox seguite questo percorso:
Strumenti/ Opzioni/ Avanzate/ Rete/ Determina come firefox si collega a internet Impostazioni.


Una volta dentro le impostazioni di connessione, ricordatevi una cosa: per navigare normalmente dovete mettere il pallino nell’opzione A,
nel momento in cui invece volete attivare il “Mio trucco” dovete spostare il pallino sull’opzione B, impostando nella casella b1 l’ip del proxy
65.111.168.207 , nella celletta b2 la porta 3128 , in fine dovete mettere il segno di spunta nella casella b3, e confermare con ok



!ATTENZIONE! Nel momento in cui attivate l’opzione B attiverete un server proxy che rallenterà momentaneamente il caricamento delle pag
tanto da renderlo impossibile.
Non vi preoccupate questa impostazione va attivata solo per un momento per poter passare con successo al punto 4 del tutorial,
dopo di che appena il vostro account premium H.H. (Happy Hour) sarà attivo potrete rimettere il pallino sull’opzione A
che vi permetterà di tornare a navigare correttamente.

Qui di seguito vi aggiungo un altro paio di server proxy da usare come alternativa in caso di problemi
(preferibilmente però usate quello indicato nella procedura, è quello consigliato, ed è anche l’unico che ho testato personalmente).

Per far funzionare il trucco bisogna usare un proxy che fa riferimento agli stati uniti.

Proxy alternativi:
proxy: 151.204.42.140 porta: 8080
proxy: 63.170.15.170 porta: 3128
proxy: 207.44.238.194 porta: 80

4) Accesso alla pagina Happy Hour di megaupload.

Ci siamo quasi il vostro account premium H.H. è a un clik di distanza….. adesso non vi rimane che aprire questo
link (
http://www.megaupload.com/premium/es/?happyhour), chevi porta alla “happy hour page” di megaupload,
se tutto è andato a buon fine vedrete il seguente risultato:



In alto sulla barra di megaupload troverete il bottone happy hour premium arancione, e nella pag la vostra login registrata un attimo fà,
sulla quale vi sono appena stati attribuiti 466 minuti (in teoria 7 ore abbondanti) di account premium H.H.+

POSIBILI PROBLEMI:


Se qualcosa non è andato a buon fine, possono essere queste le cause:


1) Non vi siete loggati sul portale di megaupload prima di cliccare sul link happy hour


2) Siete loggati correttamente e le impostazioni proxy sono corrette, ma state tentando di accedere all’ Happy hour fuori dall orario stabilito.


3) Questo messaggio invece significa che le impostazioni proxy non sono inserite/attivate o non sono corrette.

INFORMAZIONI UTILI:
Il gioco è fatto!tutta la durata dell happy hour, inserendo la vostra username e la vostra password, sul portale, oppure, “udite udite!“ dentro
megamanager; verrete sempre riconosciuti e loggati come utenti premium, con tutti i vantaggi che voi ben conoscete!

!ATTENZIONE! A questo punto non dimenticate di tornare dentro firefox per rimettere il famoso pallino sull’opzione A (vedi passo 3),
in modo da poter tornare a navigare velocemente con il vostro browser.

Andate tranquilli perché una volta loggati come premium potete fare quello che volete, aprire e chiudere megaupload e megamenager,
per tutta la durata dell H. H. verrete sempre riloggati come utenti premium.

NOTA:L’account premium permane anche se vi disconnettete e quindi cambiate ip.

SNES

SNES QUESTO EMULATORE PER psp RICREA LA MITICA GRANDEZZA DELLA CONSOL NINTENDO SNES.

INANZITUTTO UNO DEI SITI DA CUI è POSSIBILE SCARICARLO è :

http://www.psp3.org/psp/emulatori/Emulator…intendo-psp.php

UNA VOLTA FATTA QUESTA SEMPLICISSIMA OPEAZIONE ESTRAIAMO DAL FILE ZIPPATO SCARICATO LA CARTELLA: uo_Snes9x_002y32 E LA POSIZIONIAMO IN PSP/GAME.
UN’ALTRO PASSO INPORTANTE PRIMA DI TESTARE L’EMULATOREè INSERIRE I GIOCHI AL SUO INTERNO. ANDIAMO SU QUESTO SITO: http://digilander.libero.it/pianetadragonb…/games-snes.htm
E IN QUESTO http://members.xoom.virgilio.it/Brando/snes.htm
E SCARICHIAMO I GIOCHI CHE CI PIACCIONO DI PIù.
UNA VOLTA FATTA QUESTA OPERAZIONE COPIAMO NORMALMENTE I GIOCHI NELLA CARTELLA uo_Snes9x_002y32.
FATTO QUESTO SCOLLEGHIAO LA NOSTRA CONSOL DAL COMPUTER E AVVIAMO L’EMULATORE.
CI TROVEREMO DAVANTI UNA SCHERMATA CON LA LISTA DEI GIOCHI CHE ABBIAMO MESSO.
PER SPOSTARSI BISGNA PREMERE LE FRECCETTE O CON L’ANALOGICO PER SELEZIONARE IL GIOCO PREMERE IL TASTO “O” E PER USCIRE DEL GIOCO HOME/HOME/”O” CONSIGLIO QUESTO EMULATORE A CHI VA IN VACANZA E NON HA LA POSSIBILITà DI METTERE ULTERIORI GIOCHI SULLA PSP E A CHI PIACE CAMBIARE SPESSO GIOCHI. ATTENZIONE”(I GIOCHI CARICATI DEVONO ESSERE IN FORMATO .SMC SE NO NON VENGONO LETTI DALL’EMULATORE)” IO IN 1GB DI SPAZIO SONO RIUSCITO A METTERE SULL’EMULATORE QUASI 574 GIOCHI…VEDETE UN Pò VOI!!!!!!!
ALCUNE IMMAGINI DEI GIOCHI CHE SI POSSONO METTERE SULL’EMULATORE

avatar già in streming

Trama

Il film è ambientato nel 2154, sul satellite di un gigantesco pianeta gassoso, nel sistema stellare Alpha Centauri. Questo mondo è chiamato Pandora ed è molto simile alla Terra per dimensioni e forme di vita.

Una compagnia interplanetaria terrestre, la RDA, vuole conquistare questo pianeta per le sue ricchezze minerarie, soprattutto per un particolareminerale chiamato Unobtainium, superconduttore a temperatura ambiente, il cui valore di mercato è attorno ai 20 milioni della valuta corrente al chilo. Questo minerale potrebbe risolvere i gravissimi problemi energetici che ormai attanagliano la Terra da parecchi decenni.

Pandora è un mondo primordiale, ricoperto da foreste pluviali, con alberi alti fino a trecento metri e abitato da creature di tutti i tipi, tra cui degli umanoidi senzienti chiamati Na'Vi, alti tre metri e ricoperti da una pelle blu striata come le tigri. L'aria su Pandora non è respirabile dagli umani (per esplorare liberamente il pianeta, i terrestri devono indossare delle speciali maschere filtranti), così gli scienziati della RDA hanno sviluppato geneticamente una sorta di ibrido tra umano e Na'Vi, denominato "avatar". In questo modo, un essere umano può controllare un avatar collegandosi con un'interfaccia mentale: l'individuo, dopo essersi collegato con i suoi sensi nervosi, entra in una speciale capsula e in seguito cade in una sorta di coma; attraverso questo sistema riesce a utilizzare e controllare l'avatar come se fosse il suo corpo, immedesimandosi completamente con esso, e ritornando nel suo vero corpo solo quando l'avatar si addormenta.

Jake Sully, ex marine divenuto invalido e fratello gemello di uno scienziato dell'RDA ormai morto, viene scelto per una particolare missione: dato che la maggiore riserva di Unobtainium del pianeta si trova nel suolo su cui cui sorge il maggior insediamento dei Na'Vi, Jake dovrà cercare di infiltrarsi tra loro usando l'avatar preparato con il codice genetico del gemello, apprenderne usi e costumi, e cercare una soluzione diplomatica per farli spostare da quel luogo, prima che gli uomini debbano ricorrere alle armi. Con il passare del tempo, però, Jake diverrà sempre più empatico verso le cause di questo popolo, fortemente legato a Pandora e amante della natura: alla fine si innamorerà di una ragazza Na'vi, Neytiri e sarà accolto dalla tribù come uno di loro. Jake comprende così che i Na'Vi non hanno intenzione di abbandonare la propria terra. La RDA decide quindi di intervenire militarmente mandando contro il villaggio una flottiglia di elicotteri armati di missili.

Volendo salvare i Na'Vi, Jake li avverte; ma è troppo tardi, quindi sceglie di mettersi contro la RDA, combattendo insieme ai clan dei Na'Vi per la salvezza del pianeta.

Streaming Nuova Versione Video Migliore:

Megavideo CD1 : Parte1 - Parte 2-Parte 3-Parte 4
Megavideo CD2: Parte1- Parte2-Parte3-Parte4

MovShare:
Parte 1 - Parte 2
Megaupload streming: Parte1 - Parte 2
YouLoad(video): Parte1 - Parte 2
YouLoad(file): Parte1 - Parte 2

Lego foto


Lego foto è una nuova applicazione della lego per ipod touch e iphone.

Consente con facilità di caricare delle nostre foto e di trasformarle in photo create con pezzettini di lego e di salvarle direttamente sul nostro ipod touch o iphone.
l'applicazione e molto carina ed è completamente gratuita.

WinPenPack

WinPenPack è un ambiente composto da software Liberi, modificati per poter essere eseguiti da pendrive USB, senza dover essere installati.
La periferica removibile non è più un semplice supporto per l’archiviazione di dati ma diviene un vero e proprio ambiente autonomo all’interno del quale applicazioni e documenti sono integrati in modo omogeneo.
winPenPack che offre un pacchetto di applicazioni portatili che rende il tutto molto simile all’interfaccia Window.
I software portatili inclusi in winPenPack non hanno necessità di installazione, non scrivono le impostazioni nel computer ospitante e possono essere trasportati da un computer all’altro tramite un qualsiasi supporto di memorizzazione esterno, come hard disk removibili o pendrive USB.
Ci sono diversi formati di winPenPack disponibili e di applicazioni contenute.
Ecco l’elenco completo:
Grafica
X-Zphoto (permette di creare album fotografici)
X-Gimp (gestione ed elaborazione di immagini)
X-PosteRazor (consente di creare e stampare Poster di qualsiasi dimensione)
Internet
X-IpScan (IP scanner e port scanner)
X-Firefox (browser Internet)
X-FileZilla (client FTP)
X-WinSCP (permette il trasferimento dei file via SecureFTP)
X-TightVNC (controllo del desktop remoto)
X-WackGet (download manager)
X-WinHTTrack (consente di scaricare l’intero contenuto di un sito web sul proprio computer, immagini e file HTML)
X-Kompozer (editor Html per la creazione di siti web)
nPOP (mail monitor con client interno per l’invio di eMail – Supporta gMail)
X-MagicMailMonitor (mail monitor)
X-Thunderbird (client e-mail)
X-HttpFileServer (file server, scambio file via web)
X-RSSOwl (lettore RSS)
X-Miranda (instant messenger multipiattaforma, compatibile con MSN, Jabber, Yahoo, AIM, ICQ)
X-Pidgin (instant messenger compatibile con MSN, ICQ, AIM, e altri)
X-SharkTorrent (client Bit Torrent)
X-Mule (p2p )
X-MetMedic (manager di file .met per p2p, edita i file .met per recuperare i downloads persi)
X-iDC++ (p2p, client compatibile con DirectConnect e DC++)
TYPSoft FTP Server (server FTP)
Wiki on a Stick (wiki)
Multimedia
Ant Movie Catalog (catalogatore per film, DVD, VideoCD, CD, DivX)
Checkmate Mp3 Checker (analizza eventuali errori nei file Mp3)
X-dvdisaster (recupero dati da DVD e CD usurati dal tempo)
X-DivXRepair (ripara i divX danneggiati)
X-Audacity (editor audio)
X-MP3Gain (analizza e modifica i file MP3 affinché siano tutti allo stesso volume.)
X-Tractor (estrae tracce dai CD Audio)
X-VirtualDub (editing video, comprime anche in DivX)
MediaInfo (fornisce informazioni sui file video e audio)
X-InfraRecorder (masterizzazione CD/DVD)
MultiMediaCenter (multimedia center)
X-MediaPlayerClassic (ottimo sostituto multiformato di Windows Media Player)
X-VideoLAN (player multimediale)
X-ScreamerRadio (internet Radio player)
X-EasyTag (permette di vedere, modificare e scrivere le etichette dei file audio in formato MP3, MP2, MP4/AAC, FLAC, Ogg Vorbis, Monkey’s Audio e MusePack)
MediaCoder (transcoder audio-video)
Sicurezza
X-Winpooch (monitoraggio in real time e anti-spyware)
X-ClamWin (antivirus)
X-Eraser (cancellazione sicura di file e cartelle, programmabile)
LockNote (crea file di testo criptati)
X-NeoCrypt (crittografia su file/cartelle singoli/multipli, usa diversi algoritmi di cifratura)
X-TrueCrypt (creazione di dischi criptati protetti da password)
DC Firewall (firewall)
X-KeePass (archivia e protegge le password)
InstallFix Security Suite (tool spazzatutto per Windows in grado di cancellare cookie, malware e file inutili)
Sistema
X-Abakt (tool per il backup)
winMd5Sum (calcola l’MD5 checksum)
Universal Extractor (permette di estrarre/visionare il contenuto dei setup.exe)
X-7Zip (compressione/decompressione file)
X-UPXShell (compressione/decompressione file eseguibili e .dll)
JKDefrag (deframmentazione)
JKDefragTWGUI (GUI per JKDefrag)
X-WinDirStat (fornisce una dettagliata visualizzazione dello spazio occupato in cartelle, programmi, dischi fissi, cd, floppy)
Partition Logic (Floppy Disk Image e ISO Image, crea partizioni dell’Hard Disk)
X-ProcessController (controlla in real time i processi di sistema e l’attività del pc)
DiskCleaner (cancella i file inutili e temporanei)
Drive Cleanup Wizard (pulizia dei file temporanei, .bak, .tmp dal computer)
MemTest-86 (test evoluto per la RAM)
Regedt33 (editor del registro avanzato, superiore a Regedit)
X-RegShot (permette di rilevare le differenze nel registro di Windows in seguito all’installazione di un programma)
X-Pserv.cpl (elenca i servizi attivi nel sistema)
X-StartupManager (consente di visualizzare e gestire tutti i programmi che vengono eseguiti all’avvio del computer)
X-TaskSwitchXP (permette di gestire al meglio i task aperti)
X-xpy (permette profonde modifiche a Windows XP)
Sviluppo
X-WinMerge (consente di trovare le differenze fra due file di testo o due cartelle)
X-Notepad++ (text editor avanzato)
X-SciTE (editor di testo per programmatori)
X-InnoSetup (creazione di setup di installazione)
X-ISTool (plugin per Innosetup che semplifica le procedure di creazione del setup)
Web Server PAMPA (ambiente AMP: Web Server – Apache, MySQL e PHP)
Incontrissimi.com – Entra in Chat
Ufficio
X-Sunbird (calendario con funzioni di agenda)
X-Scribus (desktop publishing)
Money Manager Ex (programma per la gestione delle finanze personali)
GUIPdftk + Pdftk (coltellino svizzero per i file PDF, li unisce, divide, compatta, cripta, protegge da password)
X-Sumatra PDF (lettore di file .pdf)
X-Planner (permette di gestire e pianificare le proprie attività )
X-StarDict (traduttore istantaneo internazionale)
X-OpenOffice (suite completa per ufficio, alternativa open source a Microsoft office)
Utilities
X-GraphCalc (calcolatrice grafica)
X-CamStudio (consente di catturare l’attività del desktop e di salvarla come filmato .avi)
Ditto (tool che amplia la funzione di salvataggio nella clipboard di windows)
X-VirtuaWin (gestore di desktop virtuali, permette di creare e gestire fino a 9 desktop)
Virtual Magnifying Glass (lente di ingrandimento)
WeatherNotify (previsioni meteo in realtime)
X-AstroGrep (motore di ricerca di file e cartelle alternativo a quello incorporato in Windows)
X-ANote (post-it per pc)
Ant Renamer (permette di rinominare automaticamente liste di file)
Librerie
Aspell
Ghostscript
GTK
Lame
Java Runtime Environment

Questa miriade di programmi a disponibile gratuitamente per il download è completamente in italiano.
Non vi resta che scegliere quale fa per voi ,così d’avere sempre e ovunque i vostri programmi preferiti su chiavetta,pronti da essere usati su qualsiasi pc.

Sito web: http://www.winpenpack.com/main/news.php

rk launcher


Non avete un mac ma ogni volta che ne vedete uno desiderate la cosa che spicca di più ovvero la sua barra menù?
Problema risolto,vi è un freeware ideato proprio per voi che siete attratti da quella barra e quelle icone stratosferiche.
RkLauncher è un software “ultra-leggero” perchè lo potreste inserire facilmente sulla vostra penna USB e non prevede installazione.

Un aspetto interessante è che Rk Launcher crea da solo un collegamento con icona quando si avvia un programma per la prima volta.

pultroppo per noi si tratta ancora di una versione Beta .

ecco il link per il download

http://rk-launcher.softonic.it/download#pathbar

Alcune immagini della barra

BOWLING 3D


VALUTAZIONE 6.5/10

BOWLING 3D ci permette di giocare a bowling comodamente sdraiati sul nostro divano e con la nostra psp in mano.La grafica del gioco non è una delle migliori,ma il gioco da la possibilità di scegliere la pista che desideriamo e la palla del colore che vogliamo(ovviamente tra i modelli già presenti).

il gioco bowling 3d è un gioco che da la possibilità di giocare in modalità singolo ,partita rapida o passa e gioca.
selezionando partita rapida ,dopo un breve caricamento,visualizzeremo direttamente la pista de bowling,non ci resta che posizionare la palla come vogliamo.
con “<” e “>” spostiamo la palla rispettivamente verso sinistra e verso destra,poi schiacciando il pulsante “X”scegliamo l’intensita con qui vogliamo lanciare la palla e infine schiacciando ancora una volta il pulsante “X” scegliamo la tragliettoria della palla.
continuiamo cosi finchè non abbiamo finito la partita,i punti sono gli stessi di quelli che si usano di solito a bowling.
scegliendo invece singolo ci apparirà un menù con più possibilitò di giocata:
-CLASSICO
-STRIKE-ATONA
-SPARE-ATONA
In più la modalità allenamento e la highlights(che sarebbe la statistica dei punti a partita ,ecc..)
invece nella modalità passa e gioca si potra giocare con gli amici sulla nostra psp,come dice il titolo di questa modalità passa “la psp” e gioca

ecco alcune immagini del gioco

INVIARE SMS gratuiti con facebook


Questa applicazione permette di inviare sms illimitati in maniera del tutto gratuita,saranno sicuramente contenti di saperlo tutti gli utenti abituali di facebook.

I messaggi arrivano con un ritardo di 4/5 minuti e con il nostro nome che abbiamo inserito su Facebook.

L’utilizzo dell’applicazione è semplicissima non serve alcuna conoscenza informatica.

Vediamo cosa dobbiamo fare:

  • Per prima cosa eseguiamo l’accesso al nostro account di Facebook.
  • una volta svolta questa operazione andiamo a selezionare il pulsante delle applicazioni in basso a sinistra ed eseguire un click su sfoglia altre applicazioni
  • textiamo nella barra bianca Ricerca applicazioni la parola chatsms e premere enter.
  • Cliccare sul nome dell’applicazione appena trovata e nel caso anche su Consenti .
  • in alto a sinistra un click sulla scritta Aggiungi al mio profilo .
  • Ritorniamo sulla nostra bacheca e notiamo come nella colonna sinistra appare l’applicazione chatsms.
  • Per inviare un sms basterà scegliere il paese, inserire il numero telefonico e scrivere il messaggio(+39 per l’italia) .
  • Infine schiacciamo il tasto ” Send sms“(invia sms).

Postit:

Se non si visualizza il tasto ” Send Sms ” premete il TAB della tastiera.

ned – Scuola di sopravvivenza streming su megavideo


Nel corso di ogni episodio, il protagonista Ned si rivolge direttamente al pubblico a casa per aggiungere una nuova regola al suo manuale di sopravvivenza.

TRAMA

Alla scuola media californiana James K. Polk Ned Bigby lotta ogni giorno per sopravvivere ai compiti in classe e alle interrogazioni e ai problemi , alle prepotenze dei bulli e agli agguati dei secchioni, insieme agli amici Cookie e Moze. Intanto riesce a dare anche tanti consigli di “sopravvivenza” affrontare meglio la scuola. Tutti nella scuola conoscono la sua guida che è ricca di temi, e chiedono consigli a lui

STAGIONE 1

STAGIONE 2

simpsonizziamoci tutti!!


Per tutti gli appassionati dei Simpson è possibile creare te stesso e vedere come saresti se fossi in stile simpson!

Allora doete collegarvi sul sito dei simpson a questo indirizzo

inseguito Cliccate su Create your avatar(per creare il tuo personaggio clicca su “crea il tuo avatar dei simpson” in alto al centro)

avatar simpson

inseguito potete o registrarvi per salvare l’avatar oppure fare subito l’avatar e magari prelevarlo con un cattura schermo o con tasto stamp .

avatar simpson

Quindi vi registrate e poi cliccate su New Character, vi uscirà la scelta Male o Female

Poi procederete a creare l’avatar con occhi,naso,capelli, bocca ,ecc…

la cosa e molto semplice basta cliccare sulle frecce e selezionare quello che volete,quando avrete finito cliccate sulla freccia in basso quella bianca per scaricare l’avatar sul vostro computer.

avatar dei simpson

Nokia e le mappe gratuite


Per un'aumento delle vendite dei cellulari la strategia della nokia è stata quella di fornire mappe e la navigazione satellitare gratuita con il servizio OVI MAPS.

ora mappe e funzione vocale di navigazione Gps gratuiti su tutti i loro telefonini abilitati è gratuitamente

Nessun trucco e nessun inganno: la mappe della Navteq coprono 180 Paesi del mondo e sono scaricabili sul proprio cellulare da OviStore l tutto gratuitamente e senza dover accedere a Internet per utilizzare il servizio, così come invece accade con le mappe di Google. Panico nel mondo dei cosiddetti Pna come TomTom:a seguito dell’annuncio di Nokia è arrivata a perdere anche il 10% in borsa.

ecco il link per il download

Downlaod

VELOCIZZARE EMULe


Questa guida, con pochi passaggi ti permette di velocizzare il mulo in modo da scaricare più velocemente.

Guida:

1) Aprite Emule e andate su Opzioni > Connessione, e settiamo 125kb/s in Download senza limite e 20kb/s in Upload

2)Ora andate nella schedaOpzioni avanzate. Cercate“N° massimo nuove connessioni ogni 5 secondi”, e settate a 50. Poi cercate “N° massimo connessioni parziali aperte” e setatelo a 20. Infine cercate e selezionate la casella“Trova automaticamente il miglior limite di upload”.

Consigli

  • Per scaricare velocemente mettete più file possibili in download.
  • Scaricatefile con disponibilità ALTA!!!
  • Se avete Wind o Infostrada come gestore telefonico, dovete mettere l’opzione “Offusca Protocollo”, perchè il gestore filtra le richieste TCP/IP e diminuisce la banda in caso di utilizzo di software Peer 2 Peer.

aprire siti bloccati da adesso è un gioco da ragazzi!!!

Molti datori di lavoro e professori mettono delle limitazioni nei computer utilizzati da dipendenti o studenti per non distrarli durante l’orario di lavoro.

Ma per chi non c'è la fa a stare a meno di andare su siti come Facebook ,di giocare su dei siti che permettono di giocare gratis e online come Flashgames o di navigare su siti poco raccomandabili per il rischio di prendere virus o altro, c’è un servizio online che è in grado di oltrepassare la barriera e di preimpostata. Si chiama Blocked SiteAccess e inserendo il link diretto al sito che vogliamo visitare e cliccando su “GO” riuscirà ad accedere alla pagina che ci è stata vietata.